#ifndef NT2_INCLUDE_FUNCTIONS_SATURATE_AT_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SATURATE_AT_HPP_INCLUDED

#include <nt2/ieee/include/functions/saturate_at.hpp>

#endif
